@@ -1,10 +1,6 @@
 /* LDAPSource.h - this file is part of SOGo
  *
- * Copyright (C) 2007-2011 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
- *         Ludovic Marcotte <lmarcotte@inverse.ca>
- *         Francis Lachapelle <flachapelle@inverse.ca>
+ * Copyright (C) 2007-2015 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,10 +26,12 @@
 #include "SOGoSource.h"
 #include "SOGoConstants.h"
 
-@class NSDictionary;
-@class NSString;
-@class NGLdapConnection;
+@class LDAPSourceSchema;
 @class NGLdapEntry;
+@class NSException;
+@class NSMutableArray;
+@class NSMutableDictionary;
+@class NSString;
 
 @interface LDAPSource : NSObject <SOGoDNSource>
 {
@@ -41,6 +39,8 @@
   int queryTimeout;
 
   NSString *sourceID;
+  NSString *displayName;
+
   NSString *bindDN;       // The bindDN/password could be either the source's one
   NSString *password;     // or the current user if _bindAsCurrentUser is set to YES
   NSString *sourceBindDN; // while sourceBindDN/sourceBindPassword always belong to the source
@@ -49,31 +49,49 @@
   unsigned int port;
   NSString *encryption;
   NSString *_filter;
+  BOOL _bindAsCurrentUser;
   NSString *_scope;
+  NSString *_userPasswordAlgorithm;
 
   NSString *baseDN;
+  LDAPSourceSchema *schema;
   NSString *IDField;     // the first part of a user DN
   NSString *CNField;
   NSString *UIDField;
-  NSArray *mailFields, *searchFields;
-  NSString *IMAPHostField, *IMAPLoginField;
+  NSArray *mailFields;
+  NSArray *searchFields;
+  NSString *IMAPHostField;
+  NSString *IMAPLoginField;
+  NSString *SieveHostField;
   NSArray *bindFields;
-  BOOL _bindAsCurrentUser;
+
+  BOOL listRequiresDot;
 
   NSString *domain;
   NSString *contactInfoAttribute;
 
+  NSDictionary *contactMapping;
+  NSArray *contactObjectClasses;
+  NSArray *groupObjectClasses;
+
   NSDictionary *modulesConstraints;
 
   NSMutableArray *searchAttributes;
   
   BOOL passwordPolicy;
-
-  NSMutableDictionary *_dnCache;
+  BOOL updateSambaNTLMPasswords;
 
   /* resources handling */
   NSString *kindField;
   NSString *multipleBookingsField;
+
+  NSString *MSExchangeHostname;
+
+  /* user addressbooks */
+  NSString *abOU;
+
+  /* ACL */
+  NSArray *modifiers;
 }
 
 - (void) setBindDN: (NSString *) newBindDN
@@ -89,16 +107,23 @@
 	  UIDField: (NSString *) newUIDField
 	mailFields: (NSArray *) newMailFields
       searchFields: (NSArray *) newSearchFields
+groupObjectClasses: (NSArray *) newGroupObjectClasses
      IMAPHostField: (NSString *) newIMAPHostField
     IMAPLoginField: (NSString *) newIMAPLoginField
+    SieveHostField: (NSString *) newSieveHostField
         bindFields: (id) newBindFields
 	 kindField: (NSString *) newKindField
 andMultipleBookingsField: (NSString *) newMultipleBookingsField;
 
-- (NGLdapEntry *) lookupGroupEntryByUID: (NSString *) theUID;
-- (NGLdapEntry *) lookupGroupEntryByEmail: (NSString *) theEmail;
-- (NGLdapEntry *) lookupGroupEntryByAttribute: (NSString *) theAttribute 
-				     andValue: (NSString *) theValue;
+/* This enable the convertion of a contact entry with inetOrgPerson and mozillaAbPerson
+   to and from an LDAP record */
+- (void) setContactMapping: (NSDictionary *) newMapping
+          andObjectClasses: (NSArray *) newObjectClasses;
+
+- (NGLdapEntry *) lookupGroupEntryByUID: (NSString *) theUID
+                               inDomain: (NSString *) domain;
+- (NGLdapEntry *) lookupGroupEntryByEmail: (NSString *) theEmail
+                                 inDomain: (NSString *) domain;
 
 @end
 
