@@ -1,9 +1,6 @@
 /* NSString+Utilities.h - this file is part of SOGo
  *
- * Copyright (C) 2006-2011 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
- *         Ludovic Marcotte <lmarcotte@inverse.ca>
+ * Copyright (C) 2006-2015 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,11 +23,13 @@
 
 #import <Foundation/NSString.h>
 
+@class NSCharacterSet;
 @class NSDictionary;
 @class NSObject;
 
 @interface NSString (SOGoURLExtension)
 
+/* URL handling */
 - (NSString *) composeURLWithAction: (NSString *) action
 			 parameters: (NSDictionary *) urlParameters
 			    andHash: (BOOL) useHash;
@@ -40,13 +39,27 @@
 
 - (NSString *) stringByDetectingURLs;
 
+/* escaping */
 - (NSString *) doubleQuotedString;
 
-- (NSString *) jsonRepresentation;
-
+/* CSS and URL safety */
 - (NSString *) asCSSIdentifier;
 - (NSString *) fromCSSIdentifier;
 
+/* JavaScript safety */
+- (NSString *) asSafeJSString;
+
+/* SQL safety */
+- (NSString *) asSafeSQLString;
+
+/* Unicode safety */
+- (NSString *) safeString;
+
+/* JSON */
+- (NSString *) jsonRepresentation;
+- (BOOL) isJSONString;
+- (id) objectFromJSONString;
+
 /* bare email addresses */
 - (NSString *) pureEMailAddress;
 
@@ -54,6 +67,7 @@
 
 - (NSRange) _rangeOfURLInRange: (NSRange) refRange;
 
+/* LDAP */
 - (BOOL) caseInsensitiveMatches: (NSString *) match;
 
 #ifndef GNUSTEP_BASE_LIBRARY
@@ -62,19 +76,14 @@
 
 - (int) timeValue;
 
-- (BOOL) _isLDIFSafe;
-
-- (BOOL) isJSONString;
-
-- (id) objectFromJSONString;
-
-- (NSString *) asCryptStringUsingSalt: (NSString *) theSalt;
-- (NSString *) asMD5String;
-- (NSString *) asSHA1String;
-
-- (NSString *) asSafeSQLString;
-
+/* substrings */
 - (NSUInteger) countOccurrencesOfString: (NSString *) substring;
+- (NSString *) stringByReplacingPrefix: (NSString *) oldPrefix
+                            withPrefix: (NSString *) newPrefix;
+
+/* Those methods provide symmetric enc-/decryption via a XOR operation */
+- (NSString *) encryptWithKey: (NSString *) theKey;
+- (NSString *) decryptWithKey: (NSString *) theKey;
 
 @end
 
