@@ -1,9 +1,6 @@
 /* SOGoCache.h - this file is part of SOGo
  *
- * Copyright (C) 2008-2011 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
- *         Ludovic Marcotte <lmarcotte@inverse.ca>
+ * Copyright (C) 2008-2014 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +21,7 @@
 #ifndef SOGOCACHE_H
 #define SOGOCACHE_H
 
+#import <Foundation/Foundation.h>
 #import <Foundation/NSObject.h>
 
 #include <libmemcached/memcached.h>
@@ -98,6 +96,22 @@
                 forLogin: (NSString *) login;
 - (NSString *) userSettingsForLogin: (NSString *) theLogin;
 
+- (void) setFailedCount: (int) theCount
+               forLogin: (NSString *) theLogin;
+
+- (NSDictionary *) failedCountForLogin: (NSString *) login;
+
+- (void) setMessageSubmissionsCount: (int) theCount
+                    recipientsCount: (int) theRecipientsCount
+                           forLogin: (NSString *) theLogin;
+
+- (NSDictionary *) messageSubmissionsCountForLogin: (NSString *) theLogin;
+
+- (NSString *) distinguishedNameForLogin: (NSString *) theLogin;
+
+- (void) setDistinguishedName: (NSString *) theDN
+                     forLogin: (NSString *) theLogin;
+
 //
 // CAS support
 //
@@ -111,10 +125,15 @@
 - (void) setCASPGTId: (NSString *) pgtId
            forPGTIOU: (NSString *) pgtIou;
 
+- (void) removeCASSessionWithTicket: (NSString *) ticket;
+
+//
 // SAML2 support
+//
 - (NSDictionary *) saml2LoginDumpsForIdentifier: (NSString *) identifier;
 - (void) setSaml2LoginDumps: (NSDictionary *) dump
               forIdentifier: (NSString *) identifier;
+- (void) removeSAML2LoginDumpsForIdentifier: (NSString *) identifier;
 
 //
 // ACL caching support
