@@ -14,6 +14,31 @@ String.prototype.formatted = function() {
     return newString;
 };
 
+String.prototype.formatTime = function(hours, minutes) {
+    var newString = this;
+
+    // See http://www.gnustep.org/resources/documentation/Developer/Base/Reference/NSCalendarDate.html#method$NSCalendarDate-descriptionWithCalendarFormat$
+    var p = 'am', i = hours, m = minutes;
+    if (hours > 12) {
+        p = 'pm';
+        i = hours % 12;
+    }
+    if (minutes < 10) {
+        m = '0' + minutes;
+    }
+
+    // %H : hour as a decimal number using 24-hour clock
+    newString = newString.replace("%H", hours < 10 ? '0' + hours : hours);
+    // %I : hour as a decimal number using 12-hour clock
+    newString = newString.replace("%I", i < 10 ? '0' + i : i);
+    // %M : minute as decimal number
+    newString = newString.replace("%M", m);
+    // %p : 'am' or 'pm'
+    newString = newString.replace("%p", p);
+
+    return newString;
+};
+
 String.prototype.repeat = function(count) {
     var newString = "";
     for (var i = 0; i < count; i++) {
@@ -48,15 +73,19 @@ String.prototype.decodeEntities = function() {
                         });
 };
 
+String.prototype.unescapeHTMLEntities = function() {
+    return this.unescapeHTML().replace(/&quot;/g,'"');
+};
+
 String.prototype.asDate = function () {
     var newDate;
     var date = this.split("/");
     if (date.length == 3)
-        newDate = new Date(date[2], date[1] - 1, date[0]);
+        newDate = new Date(date[2], date[1] - 1, date[0]); // dd/mm/yyyy
     else {
         date = this.split("-");
         if (date.length == 3)
-            newDate = new Date(date[0], date[1] - 1, date[2]);
+            newDate = new Date(date[0], date[1] - 1, date[2]); // yyyy-mm-dd
         else {
             if (this.length == 8) {
                 newDate = new Date(this.substring(0, 4),
@@ -69,14 +98,39 @@ String.prototype.asDate = function () {
     return newDate;  
 };
 
-String.prototype.asCSSIdentifier = function() {
-    var characters = [ '_'  , '\\.', '#'  , '@'  , '\\*', ':'  , ','   , ' '   , "'", '&' ];
-    var escapeds =   [ '_U_', '_D_', '_H_', '_A_', '_S_', '_C_', '_CO_', '_SP_', '_SQ_', '_AM_' ];
+RegExp.escape = function(text) {
+    return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
+}
 
+var css_invalid_characters = [ '_'  ,  '.',  '#'  ,  '@'  ,  '*',  ':'  , ';'   , ','   , ' ',
+                               '(',    ')',    '[',    ']',    '{',    '}',
+                               "'",  '"',    '&',    '+' ];
+var css_escape_characters = [ '_U_',  '_D_',  '_H_',  '_A_',  '_S_',  '_C_', '_SC_', '_CO_', '_SP_',
+                              '_LP_', '_RP_', '_LS_', '_RQ_', '_LC_', '_RC_',
+                              '_SQ_', '_DQ_', '_AM_', '_P_' ];
+
+String.prototype.asCSSIdentifier = function() {
     var newString = this;
-    for (var i = 0; i < characters.length; i++) {
-        var re = new RegExp(characters[i], 'g');
-        newString = newString.replace(re, escapeds[i]);
+    for (var i = 0; i < css_invalid_characters.length; i++) {
+        var re = new RegExp(RegExp.escape(css_invalid_characters[i]), 'g');
+        newString = newString.replace(re, css_escape_characters[i]);
+    }
+
+    if (/^\d/.test(newString))
+        newString = '_' + newString;
+
+    return newString;
+};
+
+String.prototype.fromCSSIdentifier = function() {
+    var newString = this;
+
+    if (/^_\d/.test(newString))
+        newString = newString.substring(1);
+
+    for (var i = 0; i < css_escape_characters.length; i++) {
+        var re = new RegExp(css_escape_characters[i], 'g');
+        newString = newString.replace(re, css_invalid_characters[i]);
     }
 
     return newString;
@@ -88,29 +142,6 @@ Date.prototype.clone = function() {
     newDate.setTime(this.getTime());
 
     return newDate;
-}
-
-Date.prototype.sogoDayName = function() {
-    var dayName = "";
-
-    var day = this.getDay();
-    if (day == 0) {
-        dayName = labels['a2_Sunday'];
-    } else if (day == 1) {
-        dayName = labels['a2_Monday'];
-    } else if (day == 2) {
-        dayName = labels['a2_Tuesday'];
-    } else if (day == 3) {
-        dayName = labels['a2_Wednesday'];
-    } else if (day == 4) {
-        dayName = labels['a2_Thursday'];
-    } else if (day == 5) {
-        dayName = labels['a2_Friday'];
-    } else if (day == 6) {
-        dayName = labels['a2_Saturday'];
-    }
-
-    return dayName;
 };
 
 Date.prototype.deltaDays = function(otherDate) {
@@ -122,8 +153,8 @@ Date.prototype.deltaDays = function(otherDate) {
         day1 = tmp;
     }
 
-    return Math.floor((day2 - day1) / 86400000);
-}
+    return Math.round((day2 - day1) / 86400000);
+};
 
 Date.prototype.daysUpTo = function(otherDate) {
     var days = new Array();
@@ -144,7 +175,7 @@ Date.prototype.daysUpTo = function(otherDate) {
     //   var day1 = day1Date.getTime();
     //   var day2 = day2Date.getTime();
 
-    var nbrDays = Math.floor((day2 - day1) / 86400000) + 1;
+    var nbrDays = Math.round((day2 - day1) / 86400000) + 1;
     for (var i = 0; i < nbrDays; i++) {
         var newDate = new Date();
         newDate.setTime(day1 + (i * 86400000));
@@ -208,14 +239,9 @@ Date.prototype.stringWithSeparator = function(separator) {
     return str;
 };
 
-Date.prototype.sogoFreeBusyStringWithSeparator = function(separator) {
-    return this.sogoDayName() + ", " + this.stringWithSeparator(separator);
-};
-
 Date.prototype.addDays = function(nbrDays) {
-    var milliSeconds = this.getTime();
-    milliSeconds += 86400000 * nbrDays;
-    this.setTime(milliSeconds);
+    var dat = new Date(this.valueOf());
+    this.setDate(dat.getDate() + Math.round(nbrDays));
 };
 
 Date.prototype.earlierDate = function(otherDate) {
@@ -245,7 +271,7 @@ Date.prototype.beginOfDay = function() {
     beginOfDay.setMilliseconds(0);
 
     return beginOfDay;
-}
+};
   
 Date.prototype.beginOfWeek = function() {
     var offset = firstDayOfWeek - this.getDay();
