@@ -100,6 +100,7 @@ function onContactKeydown(event) {
         preventDefault(event);
         this.scrollLeft = 0;
         $(this).up('DIV').scrollLeft = 0;
+        attendeesEditor.selectedIndex = -1;
         if (this.confirmedValue)
             this.value = this.confirmedValue;
         this.hasfreebusy = false;
@@ -177,7 +178,7 @@ function onContactKeydown(event) {
 
 function performSearch(input) {
     // Perform address completion
-    if (!input.value.blank()) {
+    if (input.value.trim().length > minimumSearchLength) {
         var urlstr = (UserFolderURL
                       + "Contacts/allContactSearch?excludeGroups=1&search="
                       + encodeURIComponent(input.value));
@@ -219,10 +220,16 @@ function performSearchCallback(http) {
                     list.appendChild(node);
                     node.address = completeEmail;
                     // log("node.address: " + node.address);
-                    if (contact["c_uid"])
-                        node.uid = (contact["isMSExchange"]? UserLogin + ":" : "") + contact["c_uid"];
-                    else
+                    if (contact["c_uid"]) {
+                        var login = contact["c_uid"];
+                        if (contact["c_domain"])
+                            login += "@" + contact["c_domain"];
+                        node.uid = (contact["isMSExchange"]? UserLogin + ":" : "") + login;
+                    }
+                    else {
                         node.uid = null;
+                        node.appendChild(new Element('div').addClassName('colorBox').addClassName('noFreeBusy'));
+                    }
                     node.isList = isList;
                     if (isList) {
                         node.cname = contact["c_name"];
@@ -271,13 +278,16 @@ function performSearchCallback(http) {
             else {
                 if (document.currentPopupMenu)
                     hideMenu(document.currentPopupMenu);
-                
+
                 if (data.contacts.length == 1) {
                     // Single result
                     var contact = data.contacts[0];
-                    if (contact["c_uid"])
-                        input.uid = (contact["isMSExchange"]? UserLogin + ":" : "") + contact["c_uid"];
-                    else
+                    if (contact["c_uid"]) {
+                        var login = contact["c_uid"];
+                        if (contact["c_domain"])
+                            login += "@" + contact["c_domain"];
+                        input.uid = (contact["isMSExchange"]? UserLogin + ":" : "") + login;
+                    } else
                         input.uid = null;
                     var isList = (contact["c_component"] &&
                                   contact["c_component"] == "vlist");
@@ -387,6 +397,12 @@ function redisplayEventSpans() {
         etHour++;
     }
 
+    if (isAllDay) {
+        addDays++;
+        stHour = stMinute = 0;
+        etHour = etMinute = 0;
+    }
+
     if (stHour < displayStartHour) {
         stHour = displayStartHour;
         stMinute = 0;
@@ -428,8 +444,10 @@ function redisplayEventSpans() {
         if (currentSpanNbr > 3) {
             currentSpanNbr = 0;
             currentCellNbr++;
-            currentCell = row.cells[currentCellNbr];
-            spans = $(currentCell).childNodesWithTag("span");
+            if (currentCellNbr < row.cells.length) {
+                currentCell = row.cells[currentCellNbr];
+                spans = $(currentCell).childNodesWithTag("span");
+            }
         }
         deltaSpans--;
     }
@@ -892,9 +910,8 @@ _freeBusyCacheEntry.prototype = {
           if (this.entries.length > offset) {
               var adjustedEd = ed.beginOfDay();
               var nbrDays = adjustedSd.deltaDays(adjustedEd) + 1;
-              var nbrQu = nbrDays * 96;
-              var offsetEnd = offset + nbrQu;
-              if (this.entries.length >= offsetEnd) {
+              var offsetEnd = offset + (nbrDays * 96);
+              if (Math.round((this.entries.length - offset)/96) >= nbrDays) {
                   entries = this.entries.slice(offset, offsetEnd);
               }
           }
@@ -908,15 +925,19 @@ _freeBusyCacheEntry.prototype = {
 
       var adjustedSd = sd.beginOfDay();
       var adjustedEd = ed.beginOfDay();
-      var nbrDays = adjustedSd.deltaDays(adjustedEd) + 1;
+      var start = adjustedSd.clone();
+      start.addDays(-7);
+      var end = adjustedEd.clone();
+      end.addDays(7);
       if (this.startDate) {
           fetchDates = [];
 
           if (adjustedSd.getTime() < this.startDate.getTime()) {
-              var start = adjustedSd.clone();
-              start.addDays(-7);
-              var end = this.startDate.beginOfDay();
-              end.addDays(-1);
+              // Period extends to before current start
+              if (end.getTime() >= this.startDate.getTime()) {
+                  end = this.startDate.beginOfDay();
+                  end.addDays(-1);
+              }
               fetchDates.push({ start: start, end: end });
           }
 
@@ -924,16 +945,15 @@ _freeBusyCacheEntry.prototype = {
           var nextDate = this.startDate.clone();
           nextDate.addDays(currentNbrDays);
           if (adjustedEd.getTime() >= nextDate.getTime()) {
-              var end = nextDate.clone();
-              end.addDays(7);
-              fetchDates.push({ start: nextDate, end: end });
+              // Period extends to after current end
+              if (start.getTime() <= nextDate.getTime()) {
+                  start = nextDate.beginOfDay();
+              }
+              fetchDates.push({ start: start, end: end });
           }
       }
       else {
-          var start = adjustedSd.clone();
-          start.addDays(-7);
-          var end = adjustedEd.clone();
-          end.addDays(7);
+          // Initial range
           fetchDates = [ { start: start, end: end } ];
       }
 
@@ -941,18 +961,27 @@ _freeBusyCacheEntry.prototype = {
   },
 
   integrateEntries: function fBCE_integrateEntries(entries, start, end) {
+      var days, merged = false;
       if (this.startDate) {
           if (start.getTime() < this.startDate) {
-              var days = start.deltaDays(this.startDate);
-              if (entries.length == (days * 96)) {
+              days = start.deltaDays(this.startDate);
+              if (Math.round(entries.length/96) == days) {
+                  // New period is just before previous period
                   this.startDate = start;
                   this.entries = entries.concat(this.entries);
+                  merged = true;
               }
           }
           else {
-              this.entries = this.entries.concat(entries);
+              days = this.startDate.deltaDays(start);
+              if (Math.round(this.entries.length/96) == days) {
+                  // New period is just after previous period
+                  this.entries = this.entries.concat(entries);
+                  merged = true;
+              }
           }
-      } else {
+      }
+      if (!merged) {
           this.startDate = start;
           this.entries = entries;
       }
@@ -1039,6 +1068,8 @@ freeBusyRequest.prototype = {
                                                         this.mEnd);
               this.mListener.onRequestComplete(this, true, entries);
           }
+      } else if (http.status == 404 && this.mPendingRequests == 0) {
+          this.mListener.onRequestComplete(this, false);
       }
   }
 };
@@ -1092,13 +1123,17 @@ editorConflictHandler.prototype = {
 
   onRequestComplete: function eCH_onRequestComplete(fbRequest, success,
                                                     entries) {
-      var periodEntries = entries.slice(this.mQuOffset, this.mQuOffsetMax);
-      if (periodEntries.indexOf("1") > -1) {
-          this.mListener.onRequestComplete(this, false);
-      }
-      else {
-          this.mCurrentUid++;
-          this._step();
+      if (success) {
+          var periodEntries = entries.slice(this.mQuOffset, this.mQuOffsetMax);
+          if (periodEntries.indexOf("1") > -1) {
+              this.mListener.onRequestComplete(this, false);
+          }
+          else {
+              this.mCurrentUid++;
+              this._step();
+          }
+      } else {
+          this.mListener.onRequestComplete(this, true);
       }
   }
 };
@@ -1107,7 +1142,7 @@ function displayFreeBusyForNode(input) {
     var rowIndex = input.parentNode.parentNode.sectionRowIndex;
     var row = $("freeBusyData").tBodies[0].rows[rowIndex];
     var nodes = row.cells;
-    //log ("displayFreeBusyForNode index " + rowIndex + " (" + nodes.length + " cells)");
+    //log ("displayFreeBusyForNode index " + rowIndex + " uid " + input.uid + " (" + nodes.length + " cells)");
     if (input.uid) {
         if (!input.hasfreebusy) {
             // log("forcing draw of nodes");
@@ -1189,7 +1224,7 @@ function drawFbData(input, slots) {
     else {
         log("inconsistency between freebusy results and"
             + " the number of cells");
-        log("  expecting: " + tds.length + " received: " + slots.length);
+        log("  expecting: " + (tds.length * 4) + " received: " + slots.length);
     }
 }
 
@@ -1322,17 +1357,19 @@ function onEditorOkClick(event) {
     var endDate = getEndDate();
 
     var listener = {
-      onRequestComplete: function eCH_l_onRequestComplete(handlers, code) {
-          var label = ("A time conflict exists with one or more attendees.\n"
-                       + "Would you like to keep the current settings anyway?");
-          if (code || window.confirm(_(label))) {
-              _confirmEditorOkClick();
-          }
-      }
+        onRequestComplete: function eCH_l_onRequestComplete(handlers, code) {
+            if (code) {
+                _confirmEditorOkClick();
+            }
+            else {
+                var label = ("A time conflict exists with one or more attendees.\n"
+                             + "Would you like to keep the current settings anyway?");
+                showConfirmDialog(_('Warning'), _(label), _confirmEditorOkClick);
+            }
+        }
     };
     
-    var conflictHandler = new editorConflictHandler(uids, startDate,
-                                                    endDate, listener);
+    var conflictHandler = new editorConflictHandler(uids, startDate, endDate, listener);
     conflictHandler.start();
 }
 
@@ -1433,10 +1470,11 @@ function onTimeDateWidgetChange() {
 function prepareTableHeaders() {
     var startTimeDate = $("startTime_date");
     var startDate = startTimeDate.inputAsDate();
+    startDate.setHours(0, 0);
 
     var endTimeDate = $("endTime_date");
     var endDate = endTimeDate.inputAsDate();
-    endDate.setTime(endDate.getTime());
+    endDate.setHours(0, 0);
 
     var rows = $("freeBusyHeader").rows;
     var days = startDate.daysUpTo(endDate);
@@ -1452,14 +1490,8 @@ function prepareTableHeaders() {
         rows[0].appendChild(header1b);
         for (var hour = displayStartHour; hour < (displayEndHour + 1); hour++) {
             var header2 = document.createElement("th");
-            var text = hour + ":00";
-            if (hour < 10)
-                text = "0" + text;
-            if (hour >= dayStartHour && hour < dayEndHour)
-                $(header2).addClassName ("officeHour");
-            header2.appendChild(document.createTextNode(text));
+            header2.appendChild(document.createTextNode(timeFormat.formatTime(hour, 0)));
             rows[1].appendChild(header2);
-
             var header3 = document.createElement("th");
             for (var span = 0; span < 4; span++) {
                 var spanElement = document.createElement("span");
@@ -1643,16 +1675,19 @@ document.observe("dom:loaded", onFreeBusyLoadHandler);
 function initTimeWidgets(widgets) {
     this.timeWidgets = widgets;
 
-    assignCalendar('startTime_date');
-    assignCalendar('endTime_date');
-
-    widgets['start']['date'].observe("change", this.onAdjustTime, false);
-    widgets['start']['time'].observe("time:change", this.onAdjustTime, false);
+    jQuery(widgets['start']['date']).closest('.date').datepicker(
+        { autoclose: true, position: 'above', weekStart: parentvar('firstDayOfWeek') });
+    jQuery(widgets['start']['date']).change(onAdjustTime);
+    widgets['start']['time'].on("time:change", onAdjustTime);
     widgets['start']['time'].addInterface(SOGoTimePickerInterface);
+    widgets['start']['time'].setPosition('above');
 
-    widgets['end']['date'].observe("change", this.onAdjustTime, false);
-    widgets['end']['time'].observe("time:change", this.onAdjustTime, false);
+    jQuery(widgets['end']['date']).closest('.date').datepicker(
+        { autoclose: true, position: 'above', weekStart: parentvar('firstDayOfWeek') });
+    jQuery(widgets['end']['date']).change(onAdjustTime);
+    widgets['end']['time'].on("time:change", onAdjustTime);
     widgets['end']['time'].addInterface(SOGoTimePickerInterface);
+    widgets['end']['time'].setPosition('above');
 
     var allDayLabel = $("allDay");
     if (allDayLabel) {
@@ -1671,10 +1706,10 @@ function initTimeWidgets(widgets) {
 function onAdjustTime(event) {
     var endDate = window.getEndDate();
     var startDate = window.getStartDate();
+    var delta = 0;
     if (this.id.startsWith("start")) {
         // Start date was changed
-        var delta = window.getShadowStartDate().valueOf() -
-            startDate.valueOf();
+        delta = window.getShadowStartDate().valueOf() - startDate.valueOf();
         var newEndDate = new Date(endDate.valueOf() - delta);
         window.setEndDate(newEndDate);
         window.timeWidgets['end']['date'].updateShadowValue();
@@ -1684,20 +1719,27 @@ function onAdjustTime(event) {
     }
     else {
         // End date was changed
-        var delta = endDate.valueOf() - startDate.valueOf();  
-        if (delta < 0) {
-            alert(labels.validate_endbeforestart);
-            var oldEndDate = window.getShadowEndDate();
-            window.setEndDate(oldEndDate);
-
-            window.timeWidgets['end']['date'].updateShadowValue();
-            window.timeWidgets['end']['time'].updateShadowValue();
-            window.timeWidgets['end']['time'].onChange(); // method from SOGoTimePicker
+        delta = window.getShadowEndDate().valueOf() - endDate.valueOf();
+        if (delta != 0) {
+            var startEndDelta = endDate.valueOf() - startDate.valueOf();
+            if (startEndDelta < 0) {
+                showAlertDialog(labels.validate_endbeforestart);
+                var oldEndDate = window.getShadowEndDate();
+                window.setEndDate(oldEndDate);
+                window.timeWidgets['end']['date'].updateShadowValue();
+                window.timeWidgets['end']['time'].updateShadowValue();
+                window.timeWidgets['end']['time'].onChange(); // method from SOGoTimePicker
+            }
+            else {
+                window.timeWidgets['end']['date'].updateShadowValue();
+                window.timeWidgets['end']['time'].updateShadowValue();
+            }
         }
     }
 
-    // Specific function for the attendees editor
-    onTimeDateWidgetChange();
+    if ($("freeBusyHeader").getElementsByTagName("th").length == 0 || delta != 0)
+        // Update freebusy data
+        onTimeDateWidgetChange();
 }
 
 function _getDate(which) {
@@ -1736,6 +1778,7 @@ function getShadowEndDate() {
 
 function _setDate(which, newDate) {
     window.timeWidgets[which]['date'].setInputAsDate(newDate);
+    jQuery(window.timeWidgets[which]['date']).closest('.date').datepicker('update');
     if (!isAllDay) {
         window.timeWidgets[which]['time'].value = newDate.getDisplayHoursString();
         if (window.timeWidgets[which]['time'].onChange) window.timeWidgets[which]['time'].onChange(); // method from SOGoTimePicker
